// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
angular.module('starter', ['ionic'])

.run(function($ionicPlatform, $interval) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs).
    // The reason we default this to hidden is that native apps don't usually show an accessory bar, at
    // least on iOS. It's a dead giveaway that an app is using a Web View. However, it's sometimes
    // useful especially with forms, though we would prefer giving the user a little more room
    // to interact with the app.
    if (window.cordova && window.Keyboard) {
      window.Keyboard.hideKeyboardAccessoryBar(true);
    }

    if (window.StatusBar) {
      // Set the statusbar to use the default style, tweak this to
      // remove the status bar on iOS or change it to use white instead of dark colors.
      //StatusBar.styleDefault();
    }

    var banner_id = 'ca-app-pub-8336667990923403/8648895414';
    var interstitial_id = 'ca-app-pub-8336667990923403/9770405394';
    admob.setDevMode(false);
    admob.banner.show({ id: banner_id });
    admob.interstitial.load({ id: interstitial_id });
    $interval(function() {
      admob.interstitial.isLoaded().then((result) => {if (!result) admob.interstitial.load({ id: interstitial_id }) });
    },3*60*1000);

  });
})

.config(function($stateProvider, $urlRouterProvider, $ionicConfigProvider) {
    $stateProvider
    .state('tab', {
      url: '/tab',
      abstract: true,
      templateUrl: 'tabs.html'
    })

    .state('tab.home', {
      url: '/home',
      views: {
      'tab-home': {
        templateUrl: 'tab-home.html',
        controller: 'HomeCtrl'
        }
      }
    })

    .state('tab.favs', {
      url: '/favs',
      views: {
      'tab-favs': {
        templateUrl: 'tab-favs.html',
        controller: 'FavsCtrl'
        }
      }
    })

    .state('tab.book', {
      url: '/book',
      params: {'bookname': null},
      views: {
        'tab-home': {
          templateUrl: 'book.html',
          controller: 'BookCtrl'
        }
      }
    });

    $urlRouterProvider.otherwise('/tab/home');
    $ionicConfigProvider.tabs.position('bottom');
})

.controller('HomeCtrl', function($scope, $rootScope, $http, $state, $ionicLoading) {

    $rootScope.Home = '书库';
    $rootScope.Favorites = '收藏';
    $rootScope.Appname = '世界学术名著大全';
    $rootScope.link = 'http://res.pankon.top/PDF/世界学术名著大全';

    $scope.doRefresh = function() {
      $http({
        method :'GET',
        url : $scope.link+'/json/books.json'
      }).success(function(data,status,headers,config){
        console.log(JSON.stringify(data));
        $scope.books = data;
      }).error(function(data, status, headers, config){
        console.log("error...." + data);
      }).finally(function() {
        $scope.$broadcast('scroll.refreshComplete');
        $ionicLoading.hide();
      });
    };

    $scope.doRefresh();
    $ionicLoading.show({
      template: 'Loading...'
    });

    $scope.bookNum = function() {
      if ($scope.books) 
        return $scope.books.length;
      else
        return 0;
    };

    $scope.selectBook = function(book) {
      $state.go('tab.book', {bookname: book});
    };
})

.controller('FavsCtrl', function($scope, $rootScope) {

    $scope.favbooks = JSON.parse(localStorage.getItem("Favorites"));
    
    $rootScope.$on('favsChanged', function(event, data){
      $scope.favbooks = JSON.parse(data);
    });

    $scope.bookNum = function() {
      if ($scope.favbooks) 
        return $scope.favbooks.length;
      else
        return 0;
    };

    $scope.delFavorites = function(book, $event) {
      $event.stopPropagation();
      for (var i=0;i<$scope.favbooks.length;i++) {
        console.log(JSON.stringify($scope.favbooks[i]));
        if ($scope.favbooks[i].title == book.title) {
          $scope.favbooks.splice(i,1);
          break;
        }
      }
      localStorage.setItem("Favorites", JSON.stringify($scope.favbooks));
    };

    $scope.readBook = function(book) {
      var lastpage = localStorage.getItem(book.src);
      var flip = function (flipBook) {
        localStorage.setItem(book.src, flipBook.target._activePage);
      };
      option_df_book_full.openPage = lastpage;
      option_df_book_full.onFlip = flip;
      
      admob.interstitial.show();
    };

})

.controller('BookCtrl', function($scope, $rootScope, $http, $state, $stateParams, $ionicLoading) {

    $scope.$on('$ionicView.enter', function() {
      //console.log('ionicView.enter');
      $ionicLoading.show({
      template: 'Loading...'
      });
      $scope.basebook = $stateParams.bookname;
      $http({
        method :'GET',
        url : $rootScope.link+'/json/'+$scope.basebook.title+'.json'
      }).success(function(data,status,headers,config){
        console.log(JSON.stringify(data));
        $scope.allbooks = data;
      }).error(function(data, status, headers, config){
        console.log("error...." + data);
      }).finally(function() {
        $ionicLoading.hide();
      });
    });
    
    $scope.backHome = function() {
      $state.go('tab.home');
    };

    $scope.bookNum = function() {
      if ($scope.allbooks) 
        return $scope.allbooks.length;
      else
        return 0;
    };

    $scope.setFavorites = function(book, $event) {
      $event.stopPropagation();
      var favs = JSON.parse(localStorage.getItem("Favorites"));
      if (!favs) favs = new Array(0);
      favs.unshift(book);
      localStorage.setItem("Favorites", JSON.stringify(favs));
      $rootScope.$broadcast('favsChanged', JSON.stringify(favs));
    };

    $scope.checkFav = function(title) {
      var favs = localStorage.getItem("Favorites");
      if (favs)
        return (favs.indexOf(title) == -1);
      else
        return true;
    };

    $scope.readBook = function(book) {
      var lastpage = localStorage.getItem(book.src);
      var flip = function (flipBook) {
        localStorage.setItem(book.src, flipBook.target._activePage);
      };
      option_df_book_full.openPage = lastpage;
      option_df_book_full.onFlip = flip;
      
      admob.interstitial.show();
    };

});